summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/checkbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/checkbox.h')
-rw-r--r--kalarm/lib/checkbox.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kalarm/lib/checkbox.h b/kalarm/lib/checkbox.h
index 61d6a127..f81490ea 100644
--- a/kalarm/lib/checkbox.h
+++ b/kalarm/lib/checkbox.h
@@ -45,16 +45,16 @@ class CheckBox : public TQCheckBox
TQ_OBJECT
public:
/** Constructor.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit CheckBox(TQWidget* tqparent, const char* name = 0);
+ explicit CheckBox(TQWidget* parent, const char* name = 0);
/** Constructor.
* @param text Text to display.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- CheckBox(const TQString& text, TQWidget* tqparent, const char* name = 0);
+ CheckBox(const TQString& text, TQWidget* parent, const char* name = 0);
/** Returns true if the widget is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the check box is read-only for the user. If read-only,
@@ -45,16 +45,16 @@ class CheckBox : public TQCheckBox
public:
/** Constructor.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -45,16 +45,16 @@ class CheckBox : public TQCheckBox
/** Constructor.
* @param text Text to display.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/